@@ -170,7 +170,7 @@ class Dotfiles:
                 self.restorables,
                 prompt="Choose changes to remove from staging area: ",
                 multi=True,
-                preview=f"{self._git_str} diff --color --minimal HEAD -- " + "{}",
+                preview=f"{self._git_str} diff --color --minimal --staged -- " + "{}",
             )
             if restores is None:
                 sys_exit("No selection made. No files will be unstaged.")
@@ -328,7 +328,6 @@ class Dotfiles:
     @property
     def modified_unstaged(self) -> List[str]:
         """Returns all files with unstaged modifications or Deletions."""
-        # TODO: what about "MM " files? Modified staged changes + unstages mods
         mods = [
             line[3:] for line in self.short_status if line[:2] in [" M", " D", "MM"]
         ]
